@@ -1,4 +1,4 @@
-package App::MultiUser::Privilege::Chain;
+package App::MultiUser::Rights::Privilege::Chain;
 use strict;
 use warnings;
 
